@@ -1,11 +1,8 @@
 package Switch::Again;
+use 5.006; use strict; use warnings; our $VERSION = '0.06';
+use Struct::Match qw/struct/; 
+use base qw/Import::Export/; 
 
-use 5.006;
-use strict;
-use warnings;
-use Struct::Match qw/struct/;
-use base qw/Import::Export/;
-our $VERSION = '0.05';
 our %EX = (
 	'switch' => [qw/all/],
 	'sr' => [qw/all/]
@@ -13,21 +10,32 @@ our %EX = (
 
 BEGIN {
 	@STRUCT{qw/Regexp CODE/} = (
-		sub { $_[0] =~ $_[1]; }, 
-		sub { eval { $_[1]->($_[0]) } } 
+		sub { $_[1] =~ $_[0]; }, 
+		sub { my $v = eval { $_[0]->($_[1]) }; } 
 	);
 }
 
 sub switch {
 	my ($value, $default, @cases);
 	$value = shift if (scalar @_ % 2); 
-	$_[0] eq 'default' ? do { shift; $default = shift } : do { push @cases, { ref => $STRUCT{REF}($_[0]), case => shift, cb => shift } } 
-		while (@_); # I could map to a hash but...
+	
+	$_[0] eq 'default' 
+		? do { shift; $default = shift } 
+		: do { push @cases, { ref => $STRUCT{REF}($_[0]), case => shift, cb => shift } } 
+	while (@_); # I could map to a hash but...
+
 	my $evil = sub {
 		my ($val, @result) = ($_[0]);
-		eval {@result = $STRUCT{$_->{ref}}($val, $_->{case});} and defined $result[0] && $result[0] ne '' and do {@result = ref $_->{cb} eq 'CODE' ? $_->{cb}->($val, @result) : $_->{cb}} and last for @cases;	
-		$#result && (wantarray && @result) || shift @result or $default and $default->($val) or undef;
+		eval {
+			@result = $STRUCT{$_->{ref}}($_->{case}, $val);
+			@result = () if @result && $result[0] eq '';
+			@result;
+		} and do {
+			@result = ref $_->{cb} eq 'CODE' ? $_->{cb}->($val, @result) : $_->{cb}	
+		} and last for @cases;
+		@result ? wantarray ? @result : shift @result : $default && $default->($val);
 	};
+	
 	$value ? $evil->($value) : $evil;
 }
 
@@ -36,6 +44,8 @@ sub sr {
 	return sub {my $v589 = shift; $v589 =~ s/$search/$replace/g; $v589;};
 }
 
+1;
+
 __END__;
 
 =head1 NAME
@@ -44,7 +54,7 @@ Switch::Again - Switch`ing
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
@@ -87,6 +97,16 @@ Version 0.05
 
 =cut
 
+=head1 EXPORT
+
+=head2 switch
+ 
+=cut
+
+=head2 sr
+
+=cut
+
 =head1 AUTHOR
 
 LNATION, C<< <thisusedtobeanemail at gmail.com> >>
@@ -169,5 +189,3 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 =cut
-
-1; # End of Switch::Again
